package
Version:
v0.0.0-...-4b6f5a7
Opens a new window with list of versions in this module.
Published: Jun 29, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
const (
DefaultPort = 8200
DefaultUUIDPath = ".local/rcast/dmr_uuid.txt"
)
type Config struct {
UUIDPath string
AllowSessionPreempt bool
LinkSystemOutputVolume bool
HTTPPort int
AdvertiseIP string
IINAFullscreen bool
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.